        document.addEventListener("DOMContentLoaded", function() {
            const url = window.location.href;

            // Fetch initial rating data
            fetch(`/star-rating/fetch_ratings.php?url=${encodeURIComponent(url)}`)
                .then(response => response.json())
                .then(data => {
                    if (data.error) {
                        console.error('Error: ' + data.error);
                    } else {
                        document.getElementById('averageRating').textContent = data.average;
                        document.getElementById('voteCount').textContent = data.count;

                        // Check if user has already voted
                        if (data.userRating) {
                            document.querySelector(`.stars input[value="${data.userRating}"]`).checked = true;
                            document.getElementById('starContainer').classList.add('disabled');
                            document.querySelectorAll('.stars input').forEach(star => {
                                star.disabled = true;
                            });
                            document.getElementById("starContainer").innerHTML = `<p style="flex-direction:row-reverse;">You have already been voted <strong class='text-primary'> ${data.userRating} </strong> star's for this tool</p>`;
                        }
                    }
                })
                .catch(error => {
                    console.error('Error fetching initial data:', error);
                    console.error('An error occurred while fetching initial data.');
                });

            // Show feedback section on star rating click
            document.querySelectorAll('.stars input').forEach(star => {
                star.addEventListener('click', function() {
                    document.querySelector('.feedback').style.display = 'block';
                });
            });

            // Handle send button click
            document.getElementById('send').addEventListener('click', function() {
                var rating = document.querySelector('.stars input:checked').value;
                var feedback = document.getElementById('feedback').value;
                sendRating(rating, feedback, url);
            });

            // Handle skip button click
            document.getElementById('skip').addEventListener('click', function() {
                var rating = document.querySelector('.stars input:checked').value;
                sendRating(rating, '', url);
            });

            function sendRating(rating, feedback, url) {
                fetch('/star-rating/rate.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: 'rating=' + rating + '&feedback=' + encodeURIComponent(feedback) + '&url=' + encodeURIComponent(url)
                })
                .then(response => response.json())
                .then(data => {
                    if (data.error) {
                        console.error('Error: ' + data.error);
                    } else {
                        document.getElementById('averageRating').textContent = data.average;
                        document.getElementById('voteCount').textContent = data.count;
                        document.querySelector('.feedback').style.display = 'none';
                        document.getElementById('feedback').value = '';
                        document.getElementById('starContainer').classList.add('disabled');
                        document.querySelectorAll('.stars input').forEach(star => {
                            star.disabled = true;
                        });
                        document.cookie = `voted=${url}; max-age=31536000; path=/`;
                    }
                })
                .catch(error => {
                    console.error('Error submitting rating:', error);
                    console.error('An error occurred while submitting your rating.');
                });
            }
        });