<?php
// Main directory for storing folders based on slug
$mainDirectory = '.';

// Directory path for storing JSON files
$jsonDirectory = 'languages/en';

// Function to convert the title to a slug
function slugify($text) {
    // Convert to lowercase
    $text = strtolower($text);
    // Replace non-alphanumeric characters with hyphens
    $text = preg_replace('/[^a-z0-9]+/', '-', $text);
    // Trim hyphens from the beginning and end
    return trim($text, '-');
}

function formatDate() {
    $date = new DateTime('now', new DateTimeZone('Asia/Karachi')); // Set timezone to Pakistan
    return $date->format('j F Y'); // Format the date as "Day Month Year"
}

// Check if form is submitted
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate form data
    $title = trim($_POST['title']);
    $description = trim($_POST['description']);
    $slug = trim($_POST['slug']);
    $pageContent = trim($_POST['pageContent']);  // HTML content
    $date = formatDate();  // Get the current date in the required format

    // Ensure all fields are required
    if ($title && $description && $slug && $pageContent) {
        // Convert slug for filename and folder name
        $slug = slugify($slug);
        $image = $slug . '.webp'; // Image will be named after the slug

        // Create an associative array for the JSON structure
        $articleData = [
            'title' => $title,
            'description' => $description,
            'image' => $image,
            'date' => $date, // Add the date to the JSON structure
            'pageContent' => $pageContent
        ];

        // Ensure JSON directory exists, create it if not
        if (!is_dir($jsonDirectory)) {
            mkdir($jsonDirectory, 0777, true); // Create directory with permissions
        }

        // Full file path for JSON
        $jsonFile = $jsonDirectory . '/' . $slug . '.json';

        // Convert to JSON and save it to a file
        $jsonData = json_encode($articleData, JSON_PRETTY_PRINT);

        // Save JSON data to file
        if (file_put_contents($jsonFile, $jsonData)) {
            echo "Article data has been saved successfully as $slug.json!";

            // Create folder in the main directory named after the slug
            $articleDirectory = $mainDirectory . '/' . $slug;
            if (!is_dir($articleDirectory)) {
                mkdir($articleDirectory, 0777, true); // Create slug-based directory
            }

            // Create index.php with dynamic content
            $indexPhpContent = "<?php
include '../includes/functions.php';
\$lang = 'en';
if (isset(\$_GET['lang']) && !empty(\$_GET['lang'])) {
    \$lang = \$_GET['lang'];
}
\$page = '$slug';
\$translations = loadTranslations(\$lang, \$page);
?>
<!doctype html>
<html lang=\"<?php echo \$lang; ?>\">
<head>
    <?php include '../includes/head.php'; ?>
</head>
<body>
    <?php include '../includes/navbar.php'; ?>
    <main>
        <div class=\"container mt-5\">
            <div class=\"row\">
                <div class=\"nine columns\">
                    <?php include '../topAd.php'; ?>
                    <p class=\"breadcrumb\"><a class=\"text-white\" href=\"/\">Home</a> &nbsp;/&nbsp; <a class=\"text-white\" href=\"/<?php echo \$page; ?>/\"><?php echo \$translations['title']; ?></a></p>
                    <h1 class=\"h2\"><?php echo \$translations['title']; ?></h1>
                    <p>By Abdullah &#x2022; <?php echo \$translations['date']; ?></p>
                    <img src=\"<?php echo \$baseUrl; ?>blog-images/<?php echo \$translations['image']; ?>\" class=\"img-fluid\" alt=\"<?php echo \$translations['title']; ?>\"> 
                    <?php include '../includes/shareBtns.php'; ?> 
                </div>
                <div class=\"three columns\">
                    <?php include '../includes/sidebar.php'; ?>
                </div>
            </div>
            
            <div class=\"row page-content mt-5 mb-5 pb-5\">
                <div class=\"columns twelve\">
                    <?php echo \$translations['pageContent']; ?>
                </div>
            </div>
        </div>
    </main>
    <?php include '../includes/footer.php'; ?>
</body>
</html>";

            // Write the index.php file to the slug folder
            $indexPhpFile = $articleDirectory . '/index.php';
            file_put_contents($indexPhpFile, $indexPhpContent);
            echo " Index.php has been created successfully in $slug folder!";
        } else {
            echo "Error saving the article data.";
        }
        // Save JSON data to file for the individual article
if (file_put_contents($jsonFile, $jsonData)) {
    echo "Article data has been saved successfully as $slug.json!";
    
    // Now update the central articles.json file

    // Path to central articles.json file
    $articlesJsonFile = 'languages/en/articles.json';

    // Prepare article data for central JSON file
    $newArticle = [
        'title' => $title,
        'description' => $description,
        'slug' => $slug,
        'date' => $date,  // Use the date in the required format
        'image' => $image
    ];

    // Load the existing articles.json data
    $articles = [];
    if (file_exists($articlesJsonFile)) {
        $articles = json_decode(file_get_contents($articlesJsonFile), true);
    }

    // Append the new article to the articles array
    $articles[] = $newArticle;

    // Sort the articles array by date, newest first
    usort($articles, function ($a, $b) {
        return strtotime($b['date']) - strtotime($a['date']);
    });

    // Save the updated articles list back to articles.json
    file_put_contents($articlesJsonFile, json_encode($articles, JSON_PRETTY_PRINT));

    echo " Central articles.json has been updated successfully!";
} else {
    echo "Error saving the article data.";
}
    } else {
        echo "All fields are required!";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Article Form</title>
    <!-- Include TinyMCE (WYSIWYG text editor) -->
    <script src="https://cdn.tiny.cloud/1/w7ssu429czq0glbzktsuegb38xivv0600abi32s0u63ar2k9/tinymce/7/tinymce.min.js" referrerpolicy="origin"></script>
    <script>
        tinymce.init({
            selector: '#pageContent',
            menubar: false,
            plugins: 'link image code',
            toolbar: 'code | undo redo | blocks fontfamily fontsize | bold italic underline strikethrough | link image media table mergetags | addcomment showcomments | spellcheckdialog a11ycheck typography | align lineheight | checklist numlist bullist indent outdent | emoticons charmap | removeformat',
            height: 300
        });
    </script>
</head>
<body>
    <h1>Create an Article</h1>
    <form method="POST" action="">
        <label for="title">Title: </label><br>
        <input type="text" id="title" name="title" required><br><br>

        <label for="description">Description: </label><br>
        <input type="text" id="description" name="description" required><br><br>

        <label for="slug">Slug: </label><br>
        <input type="text" id="slug" name="slug" required><br><br>

        <label for="pageContent">Page Content: </label><br>
        <textarea id="pageContent" name="pageContent"></textarea><br><br>

        <button type="submit">Submit</button>
    </form>
</body>
</html>
